Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'jaxb/plugins/org.eclipse.jpt.jaxb.core/src/org/eclipse/jpt/jaxb/core/JaxbProject.java')
-rw-r--r--jaxb/plugins/org.eclipse.jpt.jaxb.core/src/org/eclipse/jpt/jaxb/core/JaxbProject.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/jaxb/plugins/org.eclipse.jpt.jaxb.core/src/org/eclipse/jpt/jaxb/core/JaxbProject.java b/jaxb/plugins/org.eclipse.jpt.jaxb.core/src/org/eclipse/jpt/jaxb/core/JaxbProject.java
index ca7799c966..df8afc4081 100644
--- a/jaxb/plugins/org.eclipse.jpt.jaxb.core/src/org/eclipse/jpt/jaxb/core/JaxbProject.java
+++ b/jaxb/plugins/org.eclipse.jpt.jaxb.core/src/org/eclipse/jpt/jaxb/core/JaxbProject.java
@@ -1,5 +1,5 @@
/*******************************************************************************
- * Copyright (c) 2010, 2011 Oracle. All rights reserved.
+ * Copyright (c) 2010, 2012 Oracle. All rights reserved.
* This program and the accompanying materials are made available under the
* terms of the Eclipse Public License v1.0, which accompanies this distribution
* and is available at http://www.eclipse.org/legal/epl-v10.html.
@@ -19,7 +19,7 @@ import org.eclipse.jdt.core.ICompilationUnit;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jpt.common.core.resource.java.JavaResourceAbstractType;
import org.eclipse.jpt.common.core.resource.java.JavaResourcePackage;
-import org.eclipse.jpt.common.utility.CommandExecutor;
+import org.eclipse.jpt.common.utility.command.ExtendedCommandExecutor;
import org.eclipse.jpt.common.utility.synchronizers.CallbackSynchronizer;
import org.eclipse.jpt.common.utility.synchronizers.Synchronizer;
import org.eclipse.jpt.jaxb.core.context.JaxbContextRoot;
@@ -367,20 +367,20 @@ public interface JaxbProject
// ********** modifying shared documents **********
/**
- * Set a thread-specific implementation of the {@link CommandExecutor}
+ * Set a thread-specific implementation of the {@link ExtendedCommandExecutor}
* interface that will be used to execute a command to modify a shared
* document. If necessary, the command executor can be cleared by
* setting it to null.
* This allows background clients to modify documents that are
* already present in the UI. See implementations of {@link CommandExecutor}.
*/
- void setThreadLocalModifySharedDocumentCommandExecutor(CommandExecutor commandExecutor);
+ void setThreadLocalModifySharedDocumentCommandExecutor(ExtendedCommandExecutor commandExecutor);
/**
* Return the project-wide implementation of the
- * {@link CommandExecutor} interface.
+ * {@link ExtendedCommandExecutor} interface.
*/
- CommandExecutor getModifySharedDocumentCommandExecutor();
+ ExtendedCommandExecutor getModifySharedDocumentCommandExecutor();
// ********** construction config **********

Back to the top
@@ -367,20 +367,20 @@ public interface JaxbProject
* setting it to null.
* This allows background clients to modify documents that are
- * already present in the UI. See implementations of {@link CommandExecutor}.
+ * already present in the UI. See implementations of {@link ExtendedCommandExecutor}.
*/